diff --git a/src/wp-includes/media.php b/src/wp-includes/media.php
index 11b6fae7d1..04077abe8b 100644
--- a/src/wp-includes/media.php
+++ b/src/wp-includes/media.php
@@ -1125,6 +1125,8 @@ function wp_get_attachment_image( $attachment_id, $size = 'thumbnail', $icon = f
  *                                    width and height values in pixels (in that order). Default 'thumbnail'.
  * @param bool         $icon          Optional. Whether the image should be treated as an icon. Default false.
  * @return string|false Attachment URL or false if no image is available.
+                        If `$size` doesn't match a registered image size, the original image URL
+                        will be returned.
  */
 function wp_get_attachment_image_url( $attachment_id, $size = 'thumbnail', $icon = false ) {
 	$image = wp_get_attachment_image_src( $attachment_id, $size, $icon );
diff --git a/src/wp-includes/post-thumbnail-template.php b/src/wp-includes/post-thumbnail-template.php
index 1605afa27b..c22987da14 100644
--- a/src/wp-includes/post-thumbnail-template.php
+++ b/src/wp-includes/post-thumbnail-template.php
@@ -217,8 +217,10 @@ function get_the_post_thumbnail( $post = null, $size = 'post-thumbnail', $attr =
  * @param int|WP_Post  $post Optional. Post ID or WP_Post object.  Default is global `$post`.
  * @param string|int[] $size Optional. Registered image size to retrieve the source for or a flat
  *                           array of height and width dimensions. Default 'post-thumbnail'.
- * @return string|false Post thumbnail URL or false if no URL is available.
- */
+ * @return string|false Post thumbnail URL or false if no image is available.
+                        If `$size` doesn't match a registered image size, the original image URL
+                        will be returned.
+*/
 function get_the_post_thumbnail_url( $post = null, $size = 'post-thumbnail' ) {
 	$post_thumbnail_id = get_post_thumbnail_id( $post );
 
